==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/user/messages/sv/account.php <==
<?php

return [
    '<strong>Account</strong> settings' => '<strong>Konto</strong> inställningar',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Bekräfta</strong> din nya e-postadress',
    '<strong>Permissions</strong>' => '<strong>Behörigheter</strong>',
    '<strong>User</strong> settings' => '<strong>Användar</strong> inställningar',
    '<strong>Your</strong> profile' => '<strong>Din</strong> profil',
    'All your personal data will be irrevocably deleted.' => 'All din personliga data kommer att raderas oåterkalleligt.',
    'Are you sure that you want to delete your account?' => 'Är du säker på att du vill radera ditt konto?',
    'Blocked users' => 'Blockerade användare',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Att ändra användarnamnet kan göra vissa länkar oanvändbara, till exempel gamla länkar till profilen.',
    'Confirm' => 'Bekräfta',
    'Current password' => 'Nuvarande lösenord',
    'Delete account' => 'Ta bort konto',
    'Do you really want to delete your icon image?' => 'Vill du verkligen ta bort din ikonbild?',
    'Do you really want to delete your logo image?' => 'Vill du verkligen ta bort din logotypbild?',
    'E-Mail' => 'E-Post',
    'E-Mail change' => 'Ändra e-post',
    'Enter your password to continue' => 'Ange ditt lösenord för att fortsätta',
    'Hello' => 'Hej',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Här kan du redigera dina allmänna profiluppgifter, som syns på din profilsida.',
    'Hide introduction tour panel on dashboard' => 'Dölj panelen för introduktion på tidslinjen',
    'Invalid link! Please make sure that you entered the entire url.' => 'Ogiltig länk! Se till att du angav hela webbadressen.',
    'Language' => 'Språk',
    'Modules' => 'Moduler',
    'New E-Mail address' => 'Ny e-postadress',
    'New User name' => 'Nytt användarnamn',
    'Not registered users' => 'Ej registrerade användare',
    'Notifications' => 'Aviseringar',
    'Other users' => 'Andra användare',
    'Password Recovery' => 'Återställa lösenord',
    'Permissions' => 'Behörigheter',
    'Profile' => 'Profil',
    'Profile visibility' => 'Profilens synlighet',
    'Registered users only' => 'Endast registrerade användare',
    'Save' => 'Spara',
    'Save profile' => 'Spara profil',
    'Settings' => 'Inställningar',
    'Tags' => 'Taggar',
    'The entered e-mail address is already in use by another user.' => 'Den angivna e-post adressen används redan av en annan användare.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Med dessa inställningar kan du bestämma vilka behörigheter du vill att de som besöker din profil ska ha. Varje användare kan fritt justera inställningarna för sin egen profil.',
    'TimeZone' => 'Tidszon',
    'Username has been changed' => 'Användarnamnet har ändrats',
    'Users' => 'Användare',
    'Visible for all (also unregistered users)' => 'Synlig för alla (även användare som inte är registrerade)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Vi har precis skickat ett bekräftelsemail till din nya adress. <br>Följ instruktionerna i mailet.',
    'You are currently the owner of following spaces:' => 'Du är för närvarande ägare av följande forum:',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Du har begärt att få ändra din e-postadress. <br> Din nya e-postadress är {newemail}. <br><br> För att bekräfta din nya e-postadress, klicka på knappen nedan.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Du har ändrat ditt användarnamn. <br> Ditt nya användarnamn är {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Du måste överföra äganderätten eller ta bort dessa forum innan du kan ta bort ditt konto.',
    'Your account cannot be deleted!' => 'Ditt konto kan inte raderas!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Din nuvarande e-postadress är <b> {email} </b>. Du kan ändra din nuvarande e-postadress här.',
    'Your current password can be changed here.' => 'Ditt nuvarande lösenord kan ändras här.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Ditt nuvarande användarnamn är <b> {username} </b>. Du kan ändra ditt nuvarande användarnamn här.',
    'Your e-mail address has been successfully changed to {email}.' => 'Din e-postadress har ändrats till {email}.',
    'Your friends' => 'Dina vänner',
    'Your password has been successfully changed!' => 'Ditt lösenord har ändrats!',
    'Your username has been changed' => 'Ditt användarnamn har ändrats',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Ditt användarnamn har ändrats. <br> Vi har precis skickat ett e-postmeddelande till dig med ny information.',
    '{attribute} "{value}" was not found!' => '{attribute} "{value}" kunde inte hittas!',
    'You cannot use this username.' => '',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/user/messages/sv/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => '<strong>Konto</strong>-inställningar',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Bekräfta</strong> din nya e-postadress',
    '<strong>Permissions</strong>' => '<strong>Behörigheter</strong>',
    '<strong>Your</strong> Account' => '<strong>Ditt</strong> konto',
    '<strong>Your</strong> profile' => '<strong>Din</strong> profil',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Lägg till taggar i din profil som beskriver dig och framhäver din kompetens och dina intressen. Dina taggar kommer att visas i din profil och i katalogen som listar Personer.',
    'All your personal data will be irrevocably deleted.' => 'All din personliga data kommer att raderas oåterkalleligt.',
    'Are you sure that you want to delete your account?' => 'Är du säker på att du vill radera ditt konto?',
    'Blocked users' => 'Blockerade användare',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Att ändra användarnamnet kan göra vissa länkar oanvändbara, till exempel gamla länkar till profilen.',
    'Confirm' => 'Bekräfta',
    'Current password' => 'Nuvarande lösenord',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Definiera grundläggande inställningar för din profil. Du kan lägga till de taggar som passar dig, välja språk och din tidszon och blockera otrevliga användare.',
    'Delete account' => 'Ta bort konto',
    'Do you really want to delete your icon image?' => 'Vill du verkligen ta bort din ikonbild?',
    'Do you really want to delete your logo image?' => 'Vill du verkligen ta bort din logotypbild?',
    'E-Mail' => 'E-Post',
    'E-Mail change' => 'Ändra e-post',
    'Enter your password to continue' => 'Ange ditt lösenord för att fortsätta',
    'General' => 'Allmän',
    'Hello' => 'Hej',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Här kan du redigera dina allmänna profiluppgifter, som syns på din profilsida.',
    'Hide introduction tour panel on dashboard' => 'Dölj panelen för introduktion på tidslinjen',
    'Hide my online status' => 'Dölj min onlinestatus',
    'Invalid link! Please make sure that you entered the entire url.' => 'Ogiltig länk! Se till att du angav hela webbadressen.',
    'Language' => 'Språk',
    'Markdown Editor Mode' => 'Markdown Editor-läge',
    'Modules' => 'Moduler',
    'New E-Mail address' => 'Ny e-postadress',
    'New User name' => 'Nytt användarnamn',
    'Not registered users' => 'Ej registrerade användare',
    'Notifications' => 'Aviseringar',
    'Other users' => 'Andra användare',
    'Password Recovery' => 'Återställa lösenord',
    'Permissions' => 'Behörigheter',
    'Plain' => 'Enkel',
    'Profile' => 'Profil',
    'Profile Tags' => 'Profiltaggar',
    'Profile visibility' => 'Profilens synlighet',
    'Registered users only' => 'Endast registrerade användare',
    'Rich Text' => 'Rikt textformat',
    'Save' => 'Spara',
    'Save profile' => 'Spara profil',
    'The entered e-mail address is already in use by another user.' => 'Den angivna e-post adressen används redan av en annan användare.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Med dessa inställningar kan du bestämma vilka behörigheter du vill att de som besöker din profil ska ha. Varje användare kan fritt justera inställningarna för sin egen profil.',
    'TimeZone' => 'Tidszon',
    'Username has been changed' => 'Användarnamnet har ändrats',
    'Users' => 'Användare',
    'Visible for all (also unregistered users)' => 'Synlig för alla (även användare som inte är registrerade)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Vi har precis skickat ett bekräftelsemail till din nya adress. <br>Följ instruktionerna i mailet.',
    'You are currently the owner of following spaces:' => 'Du är för närvarande ägare av följande forum:',
    'You cannot use this username.' => 'Du kan inte använda detta användarnamn.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Du har begärt att få ändra din e-postadress. <br> Din nya e-postadress är {newemail}. <br><br> För att bekräfta din nya e-postadress, klicka på knappen nedan.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Du har ändrat ditt användarnamn. <br> Ditt nya användarnamn är {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Du måste överföra äganderätten eller ta bort dessa forum innan du kan ta bort ditt konto.',
    'Your account cannot be deleted!' => 'Ditt konto kan inte raderas!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Din nuvarande e-postadress är <b> {email} </b>. Du kan ändra din nuvarande e-postadress här.',
    'Your current password can be changed here.' => 'Ditt nuvarande lösenord kan ändras här.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Ditt nuvarande användarnamn är <b> {username} </b>. Du kan ändra ditt nuvarande användarnamn här.',
    'Your e-mail address has been successfully changed to {email}.' => 'Din e-postadress har ändrats till {email}.',
    'Your friends' => 'Dina vänner',
    'Your password has been successfully changed!' => 'Ditt lösenord har ändrats!',
    'Your username has been changed' => 'Ditt användarnamn har ändrats',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Ditt användarnamn har ändrats. <br> Vi har precis skickat ett e-postmeddelande till dig med ny information.',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
];
